package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.Single;
import com.ruoyi.model.service.ISingleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 不接单信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/Single")
public class SingleController extends BaseController
{
    @Autowired
    private ISingleService singleService;

    /**
     * 查询不接单信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:Single:list')")
    @GetMapping("/list")
    public TableDataInfo list(Single single)
    {
        startPage();
        List<Single> list = singleService.selectSingleList(single);
        return getDataTable(list);
    }

    /**
     * 导出不接单信息列表
     */
    @PreAuthorize("@ss.hasPermi('model:Single:export')")
    @Log(title = "不接单信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Single single) throws IOException {
        List<Single> list = singleService.selectSingleList(single);
        ExcelUtil<Single> util = new ExcelUtil<Single>(Single.class);
        util.exportExcel(response, list, "不接单信息数据");
    }

    /**
     * 获取不接单信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:Single:query')")
    @GetMapping(value = "/{singleId}")
    public AjaxResult getInfo(@PathVariable("singleId") Long singleId)
    {
        return success(singleService.selectSingleBySingleId(singleId));
    }

    /**
     * 新增不接单信息
     */
    @PreAuthorize("@ss.hasPermi('model:Single:add')")
    @Log(title = "不接单信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Single single)
    {
        return toAjax(singleService.insertSingle(single));
    }

    /**
     * 修改不接单信息
     */
    @PreAuthorize("@ss.hasPermi('model:Single:edit')")
    @Log(title = "不接单信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Single single)
    {
        return toAjax(singleService.updateSingle(single));
    }

    /**
     * 删除不接单信息
     */
    @PreAuthorize("@ss.hasPermi('model:Single:remove')")
    @Log(title = "不接单信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{singleIds}")
    public AjaxResult remove(@PathVariable Long[] singleIds)
    {
        return toAjax(singleService.deleteSingleBySingleIds(singleIds));
    }
}
